@@ -55,23 +55,33 @@ class Client(object):
     # SQL
     def use_saved_query(self, title, cache_refresh=False, cache_ttl=86400, data_format="list"):
         query = self.workspace.saved_query.get(title)
-        return self.gen_query(sql=query['sql'], cache_refresh=cache_refresh, cache_ttl=cache_ttl, data_format=data_format)
+        return self.gen_query(
+            sql=query['sql'],
+            cache_refresh=cache_refresh,
+            cache_ttl=cache_ttl,
+            data_format=data_format)
+
     def list_saved_query(self):
         return self.workspace.saved_query.list_title()
+
     def gen_query(self, sql, cache_refresh=False, cache_ttl=86400, data_format="list"):
-        query = self.workspace.gen_query(sql, cache_refresh=cache_refresh, cache_ttl=cache_ttl, data_format=data_format);
+        query = self.workspace.gen_query(sql, cache_refresh=cache_refresh, cache_ttl=cache_ttl, data_format=data_format)
         return query
 
     # files
     def list_file(self):
         return self.workspace.file.list_absolute_path()
+
     def get_binary(self, absolute_path):
         return self.workspace.file.get_content(absolute_path)
+
     def put_binary(self, absolute_path, data):
         return self.workspace.file.put(absolute_path, data)
+
     # wrappers
     def _get_csv_wrapper(self, absolute_path, encoding='utf-8'):
         return self.workspace.file.get_csv_wrapper(absolute_path, encoding=encoding)
+
     def _get_json_wrapper(self, absolute_path, encoding='utf-8'):
         return self.workspace.file.get_json_wrapper(absolute_path, encoding=encoding)
 
@@ -87,9 +97,8 @@ class Client(object):
 
     def put_csv(self, absolute_path, data, encoding='utf-8', *args, **kwargs):
         if isinstance(data, pd.DataFrame):
-            return self.put_pandas_csv(absolute_path, data, encoding='utf-8', *args, **kwargs)
-        else:
-            return self.put_csv_str(absolute_path, data, encoding='utf-8', *args, **kwargs)
+            return self.put_pandas_csv(absolute_path, data, encoding, *args, **kwargs)
+        return self.put_csv_str(absolute_path, data, encoding, *args, **kwargs)
 
     def put_csv_str(self, absolute_path, data, encoding='utf-8', *args, **kwargs):
         str_io = StringIO()
@@ -111,9 +120,9 @@ class Client(object):
 
     def put_json(self, absolute_path, data, encoding='utf-8'):
         if isinstance(data, pd.DataFrame):
-            return self.put_pandas_json(absolute_path, data, encoding='utf-8')
+            return self.put_pandas_json(absolute_path, data, encoding)
         else:
-            return self.put_json_str(absolute_path, data, encoding='utf-8')
+            return self.put_json_str(absolute_path, data, encoding)
 
     def put_json_str(self, absolute_path, data, encoding='utf-8'):
         data = json.dumps(data).encode(encoding)
@@ -121,10 +130,11 @@ class Client(object):
 
     def put_pandas_json(self, absolute_path, data, encoding='utf-8'):
         data = data.to_json()
-        self.put_json(self, absolute_path=absolute_path, data=data, encoding=encoding)
+        self.put_json_str(absolute_path=absolute_path, data=data, encoding=encoding)
 
     # image
     def get_pil_image(self, absolute_path):
         return self._get_image_wrapper(absolute_path).to_pil()
+
     def get_np_image(self, absolute_path):
         return self._get_image_wrapper(absolute_path).to_np()
