@@ -1,7 +1,7 @@
 import requests
 import json
 import pandas
-from io import StringIO
+from io import BytesIO
 
 __all__ = ["JsonWrapper"]
 
@@ -13,12 +13,12 @@ class JsonWrapper(object):
     ):
         self.content = content
         self.encoding = encoding
-        self.content_text = content.decode(encoding)
     def to_json(self):
-        return json.loads(self.content_text.replace("'", '"'))
+        self.content_text = content.decode(encoding)
+        return json.loads(self.content_text)
     def to_pandas(self, *args, **kwargs):
         return pandas.read_json(
-            path_or_buf=StringIO(self.content_text),
+            path_or_buf=BytesIO(self.content),
             *args,
             **kwargs
         )
\ No newline at end of file
