@@ -19,7 +19,7 @@ class Workspace(object):
         self.workspace_id = workspace_id
         request = Request(
             headers=headers,
-            endpoint=endpoint
+            endpoint=self.endpoint
         )
         self.request = request
         self.saved_query = SavedQuery(
